@@ -1,7 +1,6 @@
 with_subscript_errors <- function(expr, type = "select") {
-  tryCatch(
-    with_entraced_errors(expr),
-
+  try_fetch(
+    expr,
     vctrs_error_subscript = function(cnd) {
       cnd$subscript_action <- subscript_action(type)
       cnd$subscript_elt <- "column"
@@ -10,15 +9,19 @@ with_subscript_errors <- function(expr, type = "select") {
   )
 }
 
-with_entraced_errors <- function(expr) {
+with_chained_errors <- function(expr, action, call, eval_expr = NULL) {
   try_fetch(
     expr,
-    simpleError = function(cnd) {
-      # TODO! `parent = NA`
-      abort(
-        conditionMessage(cnd),
-        call = conditionCall(cnd)
-      )
+    error = function(cnd) {
+      eval_expr <- quo_squash(eval_expr)
+      # Only display a message if there's useful context to add
+      if (!is_call(eval_expr) || identical(cnd[["call"]], call2(eval_expr[[1]])) ) {
+        msg <- ""
+      } else {
+        code <- as_label(eval_expr)
+        msg <- cli::format_inline("Problem while evaluating {.code {code}}.")
+      }
+      abort(msg, call = call, parent = cnd)
     }
   )
 }
@@ -33,7 +36,7 @@ subscript_action <- function(type) {
 validate_type <- function(type) {
   # We might add `recode` in the future
   if (!is_string(type, c("select", "rename", "pull"))) {
-    abort("Internal error: unexpected value for `tidyselect_type`")
+    cli::cli_abort("Unexpected value for {.arg tidyselect_type}.", .internal = TRUE)
   }
   type
 }
