@@ -6,14 +6,20 @@ eval_rename <- function(expr,
                         ...,
                         strict = TRUE,
                         name_spec = NULL,
+                        allow_predicates = TRUE,
                         error_call = caller_env()) {
-  ellipsis::check_dots_empty()
+  check_dots_empty()
+
+  allow_predicates <- allow_predicates && tidyselect_data_has_predicates(data)
+  data <- tidyselect_data_proxy(data)
+
   rename_impl(
     data,
     names(data),
     as_quosure(expr, env),
     strict = strict,
     name_spec = name_spec,
+    allow_predicates = allow_predicates,
     error_call = error_call
   )
 }
@@ -24,9 +30,10 @@ rename_impl <- function(x,
                         sel,
                         strict = TRUE,
                         name_spec = NULL,
+                        allow_predicates = TRUE,
                         error_call) {
   if (is_null(names)) {
-    abort("Can't rename an unnamed vector.", call = error_call)
+    cli::cli_abort("Can't rename an unnamed vector.", call = error_call)
   }
 
   pos <- eval_select_impl(
@@ -36,6 +43,7 @@ rename_impl <- function(x,
     strict = strict,
     name_spec = name_spec,
     type = "rename",
+    allow_predicates = allow_predicates,
     error_call = error_call
   )
 
@@ -45,7 +53,8 @@ rename_impl <- function(x,
     with_subscript_errors(
       vctrs::vec_as_names(
         names,
-        repair = "check_unique"
+        repair = "check_unique",
+        call = error_call
       )
     )
   }
