@@ -1,10 +1,7 @@
-#' Select or rename variables (questioning)
+#' Select or rename variables
 #'
 #' @description
-#'
-#' These functions are now in the [questioning
-#' stage](https://www.tidyverse.org/lifecycle/). They might be retired
-#' or deprecated in the future.
+#' `r lifecycle::badge("questioning")`
 #'
 #' Please use [eval_select()] and [eval_rename()] instead. See
 #' `vignette("tidyselect")` to get started.
@@ -41,7 +38,8 @@ vars_select <- function(.vars,
     exclude = .exclude,
     strict = .strict,
     name_spec = unique_name_spec,
-    uniquely_named = TRUE
+    uniquely_named = TRUE,
+    error_call = caller_env()
   )
 
   sel <- set_names(.vars[idx], names(idx))
@@ -70,7 +68,8 @@ vars_rename <- function(.vars, ..., .strict = TRUE) {
     NULL,
     .vars,
     quo(c(...)),
-    strict = .strict
+    strict = .strict,
+    error_call = caller_env()
   )
 
   .vars <- set_names(.vars)
