@@ -1,8 +1,7 @@
 test_that("errors for bad inputs", {
-  expect_error(
-    vars_pull(letters, letters),
-    class = "vctrs_error_subscript_type"
-  )
+  expect_error(vars_pull(letters, character()), "exactly one")
+  expect_error(vars_pull(letters, c("a", "b")), "exactly one")
+  expect_error(vars_pull(letters, !!c("a", "b")), "exactly one")
 
   # FIXME
   expect_error(
@@ -45,13 +44,12 @@ test_that("errors for bad inputs", {
     class = "vctrs_error_subscript_type"
   )
 
-  expect_error(
-    vars_pull(letters, !!c("a", "b")),
-    class = "vctrs_error_subscript_type"
-  )
 
   expect_snapshot(error = TRUE, {
-    vars_pull(letters, letters)
+    vars_pull(letters, character())
+    vars_pull(letters, c("a", "b"))
+    vars_pull(letters, !!c("a", "b"))
+
     vars_pull(letters, aa)
     vars_pull(letters, 0)
     vars_pull(letters, 100)
@@ -61,10 +59,14 @@ test_that("errors for bad inputs", {
     vars_pull(letters, NA)
     vars_pull(letters, na_int)
     vars_pull(letters, "foo")
-    vars_pull(letters, !!c("a", "b"))
   })
 })
 
+test_that("gives informative error if quosure is missing", {
+  f <- function(arg) vars_pull(letters, {{ arg }})
+  expect_snapshot(f(), error = TRUE)
+})
+
 test_that("can pull variables with missing elements", {
   expect_identical(vars_pull(c("a", ""), a), "a")
   expect_identical(vars_pull(c("a", NA), a), "a")
@@ -79,6 +81,16 @@ test_that("missing values are detected in vars_pull() (#72)", {
 test_that("can pull with strings", {
   expect_identical(vars_pull(letters, "b"), vars_pull(letters, b))
   expect_error(vars_pull(letters, "foo"), class = "vctrs_error_subscript_oob")
+
+  # even if those strings are numbers (#200)
+  vars <- c("-1", "0", "1")
+  expect_equal(vars_pull(vars, "-1"), "-1")
+  expect_equal(vars_pull(vars, "0"), "0")
+  expect_equal(vars_pull(vars, "1"), "1")
+})
+
+test_that("can pull with all_of() without warning", {
+  expect_identical(vars_pull(letters, all_of("z")), "z")
 })
 
 test_that("can pull with negative values", {
